/*-------------------------------------------------------------------------+
| Copyright 2018 fortiss GmbH                                              |
|                                                                          |
| Licensed under the Apache License, Version 2.0 (the "License");          |
| you may not use this file except in compliance with the License.         |
| You may obtain a copy of the License at                                  |
|                                                                          |
|    http://www.apache.org/licenses/LICENSE-2.0                            |
|                                                                          |
| Unless required by applicable law or agreed to in writing, software      |
| distributed under the License is distributed on an "AS IS" BASIS,        |
| WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. |
| See the License for the specific language governing permissions and      |
| limitations under the License.                                           |
+--------------------------------------------------------------------------*/
package org.fortiss.tooling.base.ui.annotation.editingsupport;

import java.util.Collection;

import org.eclipse.emf.ecore.EAttribute;
import org.eclipse.emf.ecore.EStructuralFeature;
import org.eclipse.jface.viewers.ColumnViewer;
import org.eclipse.jface.viewers.EditingSupport;
import org.eclipse.swt.widgets.Composite;
import org.fortiss.tooling.base.annotation.valueprovider.EStructuralFeatureDescriptor;
import org.fortiss.tooling.base.model.element.IAnnotatedSpecification;
import org.fortiss.tooling.base.model.element.IModelElement;

/**
 * {@link EditingSupport} for textual editing of multi-value annotations.
 * 
 * @author barner
 */
public class MultiValueAnnotationTextEditingSupport<T>
		extends MultiValueAnnotationEditingSupportBase<T> {

	/** Constructs a new {@link MultiValueAnnotationTextEditingSupport}. */
	public MultiValueAnnotationTextEditingSupport(ColumnViewer viewer,
			Class<? extends IAnnotatedSpecification> clazz, IAnnotatedSpecification specification,
			EStructuralFeatureDescriptor eStructuralFeatureDescriptor) {
		super(viewer, clazz, specification, eStructuralFeatureDescriptor);
	}

	/** {@inheritDoc} */
	@Override
	public IMultiValueAnnotationDialog<T> createMultiEditingDialog(Composite parent,
			IModelElement modelElement, Collection<T> values) {

		EStructuralFeature eStructuralFeature =
				eStructuralFeatureDescriptor.getEStructuralFeature(specification);

		return new MultiValueAnnotationTextEditingDialog<T>((EAttribute)eStructuralFeature, values);
	}
}
