/*-------------------------------------------------------------------------+
| Copyright 2014 fortiss GmbH                                              |
|                                                                          |
| Licensed under the Apache License, Version 2.0 (the "License");          |
| you may not use this file except in compliance with the License.         |
| You may obtain a copy of the License at                                  |
|                                                                          |
|    http://www.apache.org/licenses/LICENSE-2.0                            |
|                                                                          |
| Unless required by applicable law or agreed to in writing, software      |
| distributed under the License is distributed on an "AS IS" BASIS,        |
| WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. |
| See the License for the specific language governing permissions and      |
| limitations under the License.                                           |
+--------------------------------------------------------------------------*/
package org.fortiss.tooling.base.ui.annotation.view.generic;

import org.fortiss.tooling.base.annotation.AnnotationEntry;
import org.fortiss.tooling.base.annotation.valueprovider.AnnotationInstSpec;
import org.fortiss.tooling.base.model.element.IAnnotatedSpecification;

/**
 * Data required to identify a column displaying a particular {@link IAnnotatedSpecification} in
 * a column of the {@link GenericAnnotationView}. Used to sort columns (see
 * {@link #compareTo(ColumnHandle)}).
 * 
 * @author barner
 */
public class ColumnHandle<T extends IAnnotatedSpecification> extends AnnotationInstSpec<T>
		implements Comparable<ColumnHandle<T>> {

	/** Constructs a new {@link ColumnHandle}. */
	public ColumnHandle(AnnotationEntry entry, T annotatedSpecification) {
		super(entry, annotatedSpecification);
	}

	/**
	 * Returns the name of a column for a given {@link IAnnotatedSpecification} represented by
	 * the given {@link ColumnHandle}.
	 */
	public String getColumnName() {
		// Determine column name
		String specName =
				getEntry().getSpecificationAnnotationName(getAnnotatedSpecificationType());

		if(specName == null || specName.isEmpty()) {
			specName = "<Unnamed Annotation>";
		}
		return specName;
	}

	/** {@inheritDoc} */
	@Override
	public int compareTo(ColumnHandle<T> other) {
		String columnName = getColumnName();
		String otherColumnName = other.getColumnName();

		// Sort alphabetically by specification column label
		return columnName.compareTo(otherColumnName);
	}
}
