/*-------------------------------------------------------------------------+
| Copyright 2018 fortiss GmbH                                              |
|                                                                          |
| Licensed under the Apache License, Version 2.0 (the "License");          |
| you may not use this file except in compliance with the License.         |
| You may obtain a copy of the License at                                  |
|                                                                          |
|    http://www.apache.org/licenses/LICENSE-2.0                            |
|                                                                          |
| Unless required by applicable law or agreed to in writing, software      |
| distributed under the License is distributed on an "AS IS" BASIS,        |
| WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. |
| See the License for the specific language governing permissions and      |
| limitations under the License.                                           |
+--------------------------------------------------------------------------*/
package org.fortiss.tooling.base.ui.javafx.control.contentprovider;

import static org.fortiss.tooling.common.util.LambdaUtils.filterType;

import java.util.Collection;

import org.fortiss.tooling.base.model.element.IHierarchicElement;
import org.fortiss.tooling.common.ui.javafx.control.treetableview.DynamicTreeContentProviderBase;
import org.fortiss.tooling.kernel.model.INamedElement;

/**
 * Content provider that collects all children of the given type from an externally defined root
 * node.
 * 
 * @author diewald
 */
public class ChildrenContentProvider<T extends IHierarchicElement & INamedElement>
		extends DynamicTreeContentProviderBase<T> {

	/** {@inheritDoc} */
	@SuppressWarnings("unchecked")
	@Override
	protected Collection<? extends T> getChildren(T current) {
		// The cast is safe by the construction of the Parameter 'T'.
		return (Collection<? extends T>)filterType(current.getContainedElements(),
				INamedElement.class);
	}
}
