/*-------------------------------------------------------------------------+
| Copyright 2015 fortiss GmbH                                              |
|                                                                          |
| Licensed under the Apache License, Version 2.0 (the "License");          |
| you may not use this file except in compliance with the License.         |
| You may obtain a copy of the License at                                  |
|                                                                          |
|    http://www.apache.org/licenses/LICENSE-2.0                            |
|                                                                          |
| Unless required by applicable law or agreed to in writing, software      |
| distributed under the License is distributed on an "AS IS" BASIS,        |
| WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. |
| See the License for the specific language governing permissions and      |
| limitations under the License.                                           |
+--------------------------------------------------------------------------*/
package org.fortiss.tooling.base.ui.utils;

import static org.eclipse.ui.IPageLayout.ID_PROP_SHEET;
import static org.eclipse.ui.IWorkbenchPage.VIEW_CREATE;
import static org.eclipse.ui.IWorkbenchPage.VIEW_VISIBLE;

import org.eclipse.ui.IViewPart;
import org.eclipse.ui.IWorkbenchPage;
import org.eclipse.ui.PartInitException;
import org.eclipse.ui.PlatformUI;
import org.fortiss.tooling.base.ui.ToolingBaseUIActivator;
import org.fortiss.tooling.base.ui.annotation.view.IAnnotationViewPart;
import org.fortiss.tooling.kernel.utils.LoggingUtils;

/**
 * Utility methods for properties view.
 * 
 * @author barner
 */
public class PropertiesViewUtils {
	/** Ensures that the properties view is visible. */
	public static void raisePropertiesView() {
		try {
			IWorkbenchPage activePage =
					PlatformUI.getWorkbench().getActiveWorkbenchWindow().getActivePage();

			// If the annotations view is not visible (i.e., not opened at all, or not the active
			// tab), create and raise the properties view
			IViewPart annotationsView = activePage.findView(IAnnotationViewPart.ANNOTATION_VIEW_ID);
			if(annotationsView == null || !activePage.isPartVisible(annotationsView)) {
				activePage.showView(ID_PROP_SHEET, null, VIEW_VISIBLE);
				activePage.showView(IAnnotationViewPart.ANNOTATION_VIEW_ID, null, VIEW_CREATE);
			} else {
				// Otherwise, just create the properties view, but do not raise it (the annotation
				// view acts as a replacement for many properties)
				activePage.showView(ID_PROP_SHEET, null, VIEW_CREATE);
			}
		} catch(PartInitException e) {
			LoggingUtils.info(ToolingBaseUIActivator.getDefault(),
					"No property section to display.");
		}
	}
}
