/*-------------------------------------------------------------------------+
| Copyright 2016 fortiss GmbH                                              |
|                                                                          |
| Licensed under the Apache License, Version 2.0 (the "License");          |
| you may not use this file except in compliance with the License.         |
| You may obtain a copy of the License at                                  |
|                                                                          |
|    http://www.apache.org/licenses/LICENSE-2.0                            |
|                                                                          |
| Unless required by applicable law or agreed to in writing, software      |
| distributed under the License is distributed on an "AS IS" BASIS,        |
| WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. |
| See the License for the specific language governing permissions and      |
| limitations under the License.                                           |
+--------------------------------------------------------------------------*/
package org.fortiss.tooling.kernel.ui.internal.introspection.details.handler;

import org.conqat.ide.commons.ui.jface.TreeContentProviderBase;
import org.eclipse.jface.action.MenuManager;
import org.eclipse.jface.viewers.ITableLabelProvider;
import org.eclipse.jface.viewers.ITreeContentProvider;
import org.eclipse.jface.viewers.TableLabelProviderBase;
import org.eclipse.jface.viewers.ViewerComparator;
import org.eclipse.swt.SWT;
import org.eclipse.swt.custom.ScrolledComposite;
import org.eclipse.swt.widgets.Control;
import org.eclipse.swt.widgets.Tree;
import org.eclipse.swt.widgets.TreeColumn;
import org.eclipse.ui.dialogs.PatternFilter;
import org.fortiss.tooling.kernel.introspection.IIntrospectionItem;
import org.fortiss.tooling.kernel.service.IConstraintCheckerService;
import org.fortiss.tooling.kernel.ui.extension.IContextMenuContributor;
import org.fortiss.tooling.kernel.ui.internal.introspection.items.ContextMenuServiceIntrospectionDetailsItem;
import org.fortiss.tooling.kernel.ui.service.IContextMenuService;

/**
 * Introspection UI handler for {@link IIntrospectionItem}s provided by
 * {@link IConstraintCheckerService}.
 * 
 * @author hoelzl
 */
public final class ContextMenuServiceIntrospectionDetailsUIHandler
		extends IntrospectionDetailsUIHandlerBase {

	/** {@inheritDoc} */
	@Override
	public Control createComposite(ScrolledComposite parent) {
		String h = "Type to search registered menu contributors:";
		String f = "Number of registered menu contributors: " + getInputObject().getHandlerList();
		return createFilteredTreeInTabFolder(parent, h, f, "Registered Contributors");
	}

	/** {@inheritDoc} */
	@Override
	protected void createTreeColumns(Tree tree) {
		TreeColumn col0 = new TreeColumn(tree, SWT.LEFT);
		col0.setText("Menu Section");
		col0.setWidth(400);

		TreeColumn col1 = new TreeColumn(tree, SWT.LEFT);
		col1.setText("Menu Provider Class");
		col1.setWidth(500);
	}

	/** {@inheritDoc} */
	@Override
	protected ITreeContentProvider createContentProvider() {
		return new TreeContentProviderBase() {

			@Override
			public Object[] getChildren(Object parentElement) {
				if(parentElement == getInputObject()) {
					return IContextMenuService.MENU_SECTION_IDS;
				} else if(parentElement instanceof String) {
					return getInputObject().getHandlerList().stream()
							.filter(h -> parentElement.equals(h.getMenuSectionID())).toArray();
				}
				return null;
			}
		};
	}

	/** {@inheritDoc} */
	@Override
	protected ITableLabelProvider createLabelProvider() {
		return new TableLabelProviderBase() {
			@Override
			public String getColumnText(Object element, int columnIndex) {
				if(element instanceof String && columnIndex == 0) {
					return (String)element;
				} else if(element instanceof IContextMenuContributor) {
					IContextMenuContributor icc = (IContextMenuContributor)element;
					switch(columnIndex) {
						case 0:
							return icc.getClass().getSimpleName();
						case 1:
							return icc.getClass().getName();
					}
				}
				return "";
			}
		};
	}

	/** {@inheritDoc} */
	@Override
	protected boolean testSelection(Object selection) {
		return selection instanceof IContextMenuContributor;
	}

	/** {@inheritDoc} */
	@Override
	protected void populateContextMenu(Object selection, MenuManager mgr) {
		IContextMenuContributor c = (IContextMenuContributor)selection;
		mgr.add(createCopyClassNameAction(c.getClass()));
	}

	/** {@inheritDoc} */
	@Override
	protected PatternFilter createPatternFilter() {
		return new TableViewerPatternFilter();
	}

	/** {@inheritDoc} */
	@Override
	protected ViewerComparator createComparator() {
		return new ViewerComparator() {
			/** {@inheritDoc} */
			@Override
			public int category(Object element) {
				if(element instanceof String) {
					String section = (String)element;
					for(int i = 0; i < IContextMenuService.MENU_SECTION_IDS.length; i++) {
						if(section.equals(IContextMenuService.MENU_SECTION_IDS[i])) {
							return i;
						}
					}
					return IContextMenuService.MENU_SECTION_IDS.length;
				}
				return super.category(element);
			}
		};
	}

	/** {@inheritDoc} */
	@Override
	protected ContextMenuServiceIntrospectionDetailsItem getInputObject() {
		return (ContextMenuServiceIntrospectionDetailsItem)dataItem;
	}
}
