/*-------------------------------------------------------------------------+
| Copyright 2016 fortiss GmbH                                              |
|                                                                          |
| Licensed under the Apache License, Version 2.0 (the "License");          |
| you may not use this file except in compliance with the License.         |
| You may obtain a copy of the License at                                  |
|                                                                          |
|    http://www.apache.org/licenses/LICENSE-2.0                            |
|                                                                          |
| Unless required by applicable law or agreed to in writing, software      |
| distributed under the License is distributed on an "AS IS" BASIS,        |
| WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. |
| See the License for the specific language governing permissions and      |
| limitations under the License.                                           |
+--------------------------------------------------------------------------*/
package org.fortiss.tooling.kernel.introspection.items;

import java.util.Collection;

import org.fortiss.tooling.kernel.extension.IConstraint;
import org.fortiss.tooling.kernel.introspection.IIntrospectionDetailsItem;
import org.fortiss.tooling.kernel.service.IConstraintService;

/**
 * {@link IIntrospectionDetailsItem} for the {@link IConstraintService}.
 * 
 * @author aravantinos
 */
public class ConstraintVerificationServiceIntrospectionDetailsItem
		implements IIntrospectionDetailsItem {

	/** Read-only copy of the services handler list. */
	protected final Collection<IConstraint> handlerSet;

	/** Constructor. */
	public ConstraintVerificationServiceIntrospectionDetailsItem(
			Collection<IConstraint> handlerSet) {
		this.handlerSet = handlerSet;
	}

	/** Returns the first registration classes. */
	public Collection<IConstraint> getHandlerKeyClasses() {
		return handlerSet;
	}

	/** Returns the registered constraint of the given name. */
	public IConstraint getHandler(String name) {
		return handlerSet.stream().filter(c -> name.equals(c.getClass().getName())).findFirst()
				.get();
	}
}
