/*-------------------------------------------------------------------------+
| Copyright 2016 fortiss GmbH                                              |
|                                                                          |
| Licensed under the Apache License, Version 2.0 (the "License");          |
| you may not use this file except in compliance with the License.         |
| You may obtain a copy of the License at                                  |
|                                                                          |
|    http://www.apache.org/licenses/LICENSE-2.0                            |
|                                                                          |
| Unless required by applicable law or agreed to in writing, software      |
| distributed under the License is distributed on an "AS IS" BASIS,        |
| WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. |
| See the License for the specific language governing permissions and      |
| limitations under the License.                                           |
+--------------------------------------------------------------------------*/
package org.fortiss.tooling.spiderchart.model;

import static java.util.Objects.requireNonNull;

import java.util.HashMap;
import java.util.Map;

/**
 * Class representing series of data for each axis of a spider chart.
 * 
 * @author hoelzl
 */
public final class DataSeries {
	/** The name of the data series. */
	private String name;
	/** The points for each axis. */
	private Map<AxisBase, Object> points = new HashMap<AxisBase, Object>();

	/** Constructor. */
	public DataSeries(String name) {
		setName(name);
	}

	/** Sets name. */
	public void setName(String name) {
		this.name = requireNonNull(name);
	}

	/** Returns name. */
	public String getName() {
		return name;
	}

	/** Sets the point for the given axis. */
	public <T extends Object> void setPoint(AxisBase axis, T value) {
		points.put(requireNonNull(axis), requireNonNull(value));
	}

	/** Returns the point for the given axis. */
	public Object getAxisValue(AxisBase a) {
		return points.get(a);
	}
}
