/*-------------------------------------------------------------------------+
|                                                                          |
| Copyright 2005-2011 the ConQAT Project                                   |
|                                                                          |
| Licensed under the Apache License, Version 2.0 (the "License");          |
| you may not use this file except in compliance with the License.         |
| You may obtain a copy of the License at                                  |
|                                                                          |
|    http://www.apache.org/licenses/LICENSE-2.0                            |
|                                                                          |
| Unless required by applicable law or agreed to in writing, software      |
| distributed under the License is distributed on an "AS IS" BASIS,        |
| WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. |
| See the License for the specific language governing permissions and      |
| limitations under the License.                                           |
+-------------------------------------------------------------------------*/
package org.conqat.ide.commons.ui.swt;

import org.eclipse.swt.events.SelectionAdapter;
import org.eclipse.swt.events.SelectionEvent;
import org.eclipse.swt.graphics.Rectangle;
import org.eclipse.swt.layout.FormAttachment;
import org.eclipse.swt.layout.FormData;
import org.eclipse.swt.layout.FormLayout;
import org.eclipse.swt.widgets.Control;
import org.eclipse.swt.widgets.Sash;

/**
 * Utility code for dealing with {@link FormLayout} and {@link FormData}.
 * 
 * @author $Author: $
 * @version $Rev: $
 * @ConQAT.Rating GREEN Hash: 8441C98CD5E79EE59E74FBECA4ABF00C
 */
public class FormLayoutUtils {

	/** Creates a new {@link FormData} object. */
	public static FormData createFormData(int width, int height,
			FormAttachment left, FormAttachment right, FormAttachment top,
			FormAttachment bottom) {
		FormData formData = new FormData(width, height);
		formData.left = left;
		formData.right = right;
		formData.top = top;
		formData.bottom = bottom;
		return formData;
	}

	/**
	 * Sets up the given controls using form layout in a fashion that the sash
	 * acts as a splitter. The sash will get a listener to resize the controls
	 * upon movement. The implementation roughly follows this <a href="http://dev.eclipse.org/viewcvs/viewvc.cgi/org.eclipse.swt.snippets/src/org/eclipse/swt/snippets/Snippet107.java?view=co"
	 * >snipped</a>.
	 * 
	 * 
	 * @param sashWidth
	 *            the width of the sash.
	 * @param minWidth
	 *            the smallest width of both controls when moving.
	 */
	public static void performVerticalSashSplitSetup(Control left,
			final Sash sash, Control right, int sashWidth, final int minWidth) {
		left.setLayoutData(createFormData(minWidth, minWidth,
				new FormAttachment(0, 0), new FormAttachment(sash),
				new FormAttachment(0, 0), new FormAttachment(100, 0)));

		final FormData sashData = createFormData(sashWidth, sashWidth,
				new FormAttachment(50, 0), null, new FormAttachment(0, 0),
				new FormAttachment(100, 0));
		sash.setLayoutData(sashData);

		right.setLayoutData(createFormData(minWidth, minWidth,
				new FormAttachment(sash), new FormAttachment(100, 0),
				new FormAttachment(0, 0), new FormAttachment(100, 0)));

		sash.addSelectionListener(new SelectionAdapter() {

			/** {@inheritDoc} */
			@Override
			public void widgetSelected(SelectionEvent e) {
				Rectangle sashRect = sash.getBounds();
				Rectangle shellRect = sash.getParent().getClientArea();
				int right = shellRect.width - sashRect.width - minWidth;
				e.x = Math.max(Math.min(e.x, right), minWidth);
				if (e.x != sashRect.x) {
					sashData.left = new FormAttachment(0, e.x);
					sash.getParent().layout();
				}
			}
		});
	}
}
